@@ -708,7 +708,11 @@ void MainWindow::createToolBox()
                    "mixer.json",
                    "lpf.json",
                    "bpf.json",
-                   "hpf.json"
+                   "hpf.json",
+                   "phase.json",
+                   "phaseVar.json",
+                   "circulator.json",
+                   "antenna.json"
     };
     paths<<":/libs/signal/";
     names<<tr("Signal Processing");
@@ -2486,6 +2490,7 @@ void MainWindow::linePatternChanged()
  * better handlers when zoomed out ?
  * cut line
  * manhattan routing
+ * free rotate (graphical, number)
  * export wider to entail wider lines ?
  * user elements -> order ?
  * fix flip/rotate when moving/dragging several elements
